@@ -2,7 +2,7 @@ package Bundle::dualLived;
 
 use strict;
 
-$Bundle::dualLived::VERSION = '0.00_04';
+$Bundle::dualLived::VERSION = '0.00_05';
 
 1;
 
@@ -60,6 +60,8 @@ CGI
 
 CPAN
 
+CPAN::Meta::YAML
+
 CPANPLUS
 
 CPANPLUS::Dist::Build
@@ -118,6 +120,8 @@ Filter::Util::Call
 
 Getopt::Long
 
+HTTP::Tiny
+
 I18N::LangTags
 
 IO
@@ -130,6 +134,8 @@ IPC::Cmd
 
 IPC::Msg
 
+JSON::PP
+
 List::Util
 
 Locale::Constants
@@ -162,6 +168,8 @@ Module::Load::Conditional
 
 Module::Loaded
 
+Module::Metadata
+
 Module::Pluggable
 
 NEXT
@@ -174,6 +182,8 @@ Params::Check
 
 Parse::CPAN::Meta
 
+Perl::OSType
+
 PerlIO::via::QuotedPrint
 
 Pod::Checker
@@ -248,11 +258,11 @@ XSLoader
 
 =head1 AUTHOR
 
-Version 0.00_04 Kevin W. Henwood, <Khen1950fx@aol.com>
+Version 0.00_05 Kevin W. Henwood, <Khen1950fx@aol.com>
 
 head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Kevin W. Henwood
+Copyright (C) 2010, 2011 by Kevin W. Henwood
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
